package cz.zcu.courseware.stag;

import org.springframework.jdbc.core.namedparam.NamedParameterJdbcDaoSupport;
import org.apache.log4j.Logger;

import java.util.*;

/**
 * User: carney
 * Date: 4.12.2006
 * Time: 17:44:04
 */
public class PredmetDAOImpl extends NamedParameterJdbcDaoSupport implements PredmetDAO {
  public static final Logger logger = Logger.getLogger(PredmetDAOImpl.class);
	private static final boolean isDebugEnabled = logger.isDebugEnabled();

  /**
   * Zjisti vsechny predmety ktere odpovidaji zadanym zkratkam.
   *
   * @param zkrPrac
   *            Zkratka pracoviste. Nemusi byt zadano.
   * @param zkrPredm
   *            Zkratka predmetu. Nemusi byt zadano.
   * @param l
   *            locale
   * @return Seznam predmetu. Polozky:
   *         <ul>
   *         <li><tt>'pk_prac_zkr' [String]</tt>- Zkratka pracoviste. <b>STAG </b>: <tt>'PRED_VARIANTY.PRAC_ZKR'</tt>
   *         <li><tt>'pk_rok_varianty' [String]</tt>- Rok varianty. <b>STAG </b>: <tt>'PRED_VARIANTY.ROK_VARIANTY'</tt>
   *         <li><tt>'pk_zkr_predm' [String]</tt>- Zkratka predmetu. <b>STAG </b>: <tt>'PRED_VARIANTY.ZKR_PREDM'</tt>
   *         <li><tt>'nazev_predmetu' [String]</tt>- Nazev predmetu <b>STAG </b>: <tt>'PRED_VARIANTY.CZ_NAZEV'</tt> nebo
   *         <tt>'PRED_VARIANTY.AN_NAZEV'</tt>
   *         </ul>
   */
  public ArrayList getPredmetByZkr(String zkrPrac, String zkrPredm, Locale l) {
    String lang = l.getLanguage();
    String sql = " select p.prac_zkr as pk_prac_zkr, p.zkr_predm as pk_zkr_predm, p.rok_varianty as pk_rok_varianty, " +
            "	DECODE(?, 'cs', p.cz_nazev, 'sk', p.cz_nazev, NVL(p.an_nazev, p.cz_nazev)) AS nazev_predmetu " +
            " from pred_varianty p where p.PRAC_ZKR like translate(nls_upper(nvl(?,'%')),'*','%') " +
            "	and p.ZKR_PREDM like translate(nvl(upper(?),'%'),'*','%')	And p.ROK_VARIANTY = (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)) " +
            " order by p.PRAC_ZKR, p.ZKR_PREDM, p.ROK_VARIANTY";

    logger.debug("getPredmetByZkr - BEGIN, zkrPrac: " + zkrPrac + ", zkrPredm: " + zkrPredm );

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[] {lang, zkrPrac, zkrPredm}));
  } // getPredmetByZkr

  /**
   * Zjisti vsechny garanty zadaneho predmetu.
   *
   * @param katedra
   *            Zkratka pracoviste. Musi byt zadano.
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano.
   * @return Seznam garantu. Polozky:
   *         <ul>
   *         <li><tt>'pk_ucitidno' [BigDecimal]</tt>- Id ucitele. <b>STAG </b>: <tt>'UCITELE.UCITIDNO'</tt>
   *         <li><tt>'jmeno' [String]</tt>- Jmeno ucitele. <b>STAG </b>: <tt>'UCITELE.JMENO'</tt>
   *         <li><tt>'prijmeni' [String]</tt>- Prijmeni ucitele <b>STAG </b>: <tt>'UCITELE.PRIJMENI'</tt>
   *         <li><tt>'titul_pred' [String]</tt>- Titul pred jmenem ucitele. <b>STAG </b>:
   *         <tt>'UCITELE.TITUL_PRED' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'titul_za' [String]</tt>- Titul za jmenem ucitele. <b>STAG </b>:
   *         <tt>'UCITELE.TITUL_ZA' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'ucitel' [String]</tt>- Cele jmeno ucitele. <b>STAG </b>: <tt>'UCITELE.JMENO' + 'UCITELE.PRIJMENI'</tt>
   *         </ul>
   */
  public List getGaranti(String katedra, String predmet, String rokVar, String lng) {
    String sql = " select u.UCITIDNO as pk_ucitidno, u.JMENO, u.PRIJMENI, DECODE(?, 'cs', c1.RV_ABBREVIATION, 'sk', c1.RV_ABBREVIATION, NVL(c1.english, c1.RV_ABBREVIATION)) AS titul_pred," +
            "	   DECODE(?, 'cs', c2.RV_ABBREVIATION, 'sk', c2.RV_ABBREVIATION, NVL(c2.english, c2.RV_ABBREVIATION)) AS titul_za," +
            "	   DECODE(u.TITUL_PRED, NULL, NULL, c1.RV_ABBREVIATION||' ')||u.JMENO||' '||u.PRIJMENI||DECODE(u.TITUL_ZA, NULL, NULL,', '||c2.RV_ABBREVIATION) as ucitel" +
            " from ucitele u, ucitele_predmetu up, cg_ref_codes c1, cg_ref_codes c2 where up.ZKR_PREDM = UPPER(?)	  and up.PRAC_ZKR = UPPER(?)" +
            "	  and up.ROK_VARIANTY = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))   and up.GARANT = 'A'  and u.UCITIDNO = up.UCITIDNO" +
            "	  and c1.RV_DOMAIN(+) = 'TITUL_PRED'  and c1.RV_LOW_VALUE(+) = u.TITUL_PRED	  and c2.RV_DOMAIN(+) = 'TITUL_ZA'" +
            "	  and c2.RV_LOW_VALUE(+) = u.TITUL_ZA order by u.PRIJMENI, u.JMENO";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lng, lng, predmet, katedra,rokVar}));
  }

	public List getGarantiWithLogin(String katedra, String predmet, String rokVar, String lng) {
    String sql = " select u.UCITIDNO as pk_ucitidno, u.JMENO, u.PRIJMENI, DECODE(?, 'cs', c1.RV_ABBREVIATION, 'sk', c1.RV_ABBREVIATION, NVL(c1.english, c1.RV_ABBREVIATION)) AS titul_pred," +
            "	   DECODE(?, 'cs', c2.RV_ABBREVIATION, 'sk', c2.RV_ABBREVIATION, NVL(c2.english, c2.RV_ABBREVIATION)) AS titul_za," +
            "	   DECODE(u.TITUL_PRED, NULL, NULL, c1.RV_ABBREVIATION||' ')||u.JMENO||' '||u.PRIJMENI||DECODE(u.TITUL_ZA, NULL, NULL,', '||c2.RV_ABBREVIATION) as ucitel, ou.username as login" +
            " from ucitele u, ucitele_predmetu up, orion_ucitele ou,  cg_ref_codes c1, cg_ref_codes c2 where up.ZKR_PREDM = UPPER(?)	  and up.PRAC_ZKR = UPPER(?)" +
            "	  and up.ROK_VARIANTY = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))   and up.GARANT = 'A'  and u.UCITIDNO = up.UCITIDNO" +
            "	  and c1.RV_DOMAIN(+) = 'TITUL_PRED'  and c1.RV_LOW_VALUE(+) = u.TITUL_PRED	  and c2.RV_DOMAIN(+) = 'TITUL_ZA'" +
            "	  and c2.RV_LOW_VALUE(+) = u.TITUL_ZA  and u.ucitidno = ou.ucitidno order by u.PRIJMENI, u.JMENO";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lng, lng, predmet, katedra,rokVar}));
  }



  /**
   * Zjisti prednasejici na zaklade vypsanych studijnich akci.
   * Timto se resi ten problem, ze do STAGu sekretarky (nebo kdo???) nevypisuji k hlavickam predmetu nikoho krome garantu.
   *
   * @param katedra
   *            Zkratka katedry (pracoviste). Musi byt zadano.
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano.
   * @param rokVar
   *            Rok varianty predmetu. Musi byt zadano.
   *
   * @return Seznam prednasejicich, kazda polozka seznamu je HashMap s temito polozkami (lowercase):
   *         <ul>
   *         <li>PK_UcitIDNO - BigDecimal - ID No ucitele.</li>
   *         <li>Jmeno - String - Jmeno ucitele.</li>
   *         <li>Prijmeni - String - Prijmeni ucitele.</li>
   *         <li>Titul_Pred - String - Predni titul.</li>
   *         <li>Titul_Za - String - Zadni titul.</li>
   *         <li>Ucitel - String - Cele jmeno vcetne titulu.</li>
   *         </ul>
   */
  public List getPrednasejiciPodleStudijnichAkci(String katedra, String predmet, String rokVar, String lng) {
	  String sql = "SELECT DISTINCT \n" +
	               "  RA.UcitIDNO AS PK_UcitIDNO, \n" +
	               "  U.Jmeno AS Jmeno, \n" +
	               "  U.Prijmeni AS Prijmeni, \n" +
	               "  DECODE(:lang, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred, \n" +
	               "  DECODE(:lang, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za, \n" +
	               "  DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel \n" +
	               "FROM \n" +
	               "  Rozvrh_Akce RA, \n" +
	               "  Ucitele U, \n" +
	               "  CG_Ref_Codes C1, \n" +
	               "  CG_Ref_Codes C2 \n" +
	               "WHERE \n" +
	               "  RA.Prac_Zkr = UPPER(:katedra) \n" +
	               "  AND RA.Zkr_Predm = UPPER(:predmet) \n" +
	               "  AND RA.Rok_Platnosti = nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE))) \n" +
	               "  AND RA.TypAkce = 'P\u0159'  \n" +
	               "  AND RA.UcitIDNO = U.UcitIDNO \n" +
	               "  AND C1.RV_DOMAIN(+) = 'TITUL_PRED' \n" +
	               "  AND C1.RV_LOW_VALUE(+) = U.Titul_Pred \n" +
	               "  AND C2.RV_DOMAIN(+) = 'TITUL_ZA' \n" +
	               "  AND C2.RV_LOW_VALUE(+) = U.Titul_Za";
    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lng, lng, katedra, predmet, rokVar}));
  }

	public List getPrednasejiciPodleStudijnichAkciWithLogin(String katedra, String predmet, String rokPlatnosti,  String lng) {
    String sql =	"   SELECT DISTINCT RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni," +
			"	   DECODE(?, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred," +
			"	   DECODE(?, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za," +
			"	   DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel, ou.username as login" +
			"     FROM Rozvrh_Akce RA, Ucitele U, orion_ucitele ou, CG_Ref_Codes C1, CG_Ref_Codes C2" +
			"    WHERE RA.Prac_Zkr = UPPER(?)" +
			"      AND RA.Zkr_Predm = UPPER(?)" +
			"      AND RA.Rok_Platnosti = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))" +
			"      AND RA.TypAkce = 'P\u0159'" + // Tohle je desnej hnus, v ty DB je to fakt s hackem
			"      AND RA.UcitIDNO = U.UcitIDNO" +
			"      AND C1.RV_DOMAIN(+) = 'TITUL_PRED'" +
			"      AND C1.RV_LOW_VALUE(+) = U.Titul_Pred" +
			"      AND C2.RV_DOMAIN(+) = 'TITUL_ZA'" +
			"      AND C2.RV_LOW_VALUE(+) = U.Titul_Za" +
			"      AND ou.ucitidno = u.ucitidno order by u.PRIJMENI, u.JMENO";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lng, lng, katedra, predmet,rokPlatnosti}));
  }

  /**
   * Zjisti seminarici na zaklade vypsanych studijnich akci.
   * Timto se resi ten problem, ze do STAGu sekretarky (nebo kdo???) nevypisuji k hlavickam predmetu nikoho krome garantu.
   *
   * @param katedra
   *            Zkratka pracoviste. Musi byt zadano.
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano.
   *            Zkratka predmetu. Musi byt zadano.
   * @param rokVar
   *            Rok varianty predmetu. Musi byt zadano.
   *
   * @return Seznam prednasejicich, kazda polozka seznamu je HashMap s temito polozkami (lowercase):
   *         <ul>
   *         <li>PK_UcitIDNO - BigDecimal - ID No ucitele.</li>
   *         <li>Jmeno - String - Jmeno ucitele.</li>
   *         <li>Prijmeni - String - Prijmeni ucitele.</li>
   *         <li>Titul_Pred - String - Predni titul.</li>
   *         <li>Titul_Za - String - Zadni titul.</li>
   *         <li>Ucitel - String - Cele jmeno vcetne titulu.</li>
   *         </ul>
   */
  public List getSeminariciPodleStudijnichAkci(String katedra, String predmet, String rokVar, String lang) {
    String sql = "   SELECT DISTINCT RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni," +
			"	   DECODE(?, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred," +
			"	   DECODE(?, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za," +
			"	   DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel" +
			"     FROM Rozvrh_Akce RA, Ucitele U, CG_Ref_Codes C1, CG_Ref_Codes C2" +
			"    WHERE RA.Prac_Zkr = UPPER(?)" +
			"      AND RA.Zkr_Predm = UPPER(?)" +
			"      AND RA.Rok_Platnosti = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))" +
			"      AND RA.TypAkce = 'Se'" +
			"      AND RA.UcitIDNO = U.UcitIDNO" +
			"      AND C1.RV_DOMAIN(+) = 'TITUL_PRED'" +
			"      AND C1.RV_LOW_VALUE(+) = U.Titul_Pred" +
			"      AND C2.RV_DOMAIN(+) = 'TITUL_ZA'" +
			"      AND C2.RV_LOW_VALUE(+) = U.Titul_Za";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lang, lang, katedra, predmet, rokVar}));
  }

	public List getSeminariciPodleStudijnichAkciWithLogin(String katedra, String predmet,  String rokPlatnosti, String lang) {
    String sql = "   SELECT DISTINCT RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni," +
			"	   DECODE(?, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred," +
			"	   DECODE(?, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za," +
			"	   DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel, ou.username as login" +
			"     FROM Rozvrh_Akce RA, Ucitele U, orion_ucitele ou,  CG_Ref_Codes C1, CG_Ref_Codes C2" +
			"    WHERE RA.Prac_Zkr = UPPER(?)" +
			"      AND RA.Zkr_Predm = UPPER(?)" +
			"      AND RA.Rok_Platnosti = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))" +
			"      AND RA.TypAkce = 'Se'" +
			"      AND RA.UcitIDNO = U.UcitIDNO" +
			"      AND C1.RV_DOMAIN(+) = 'TITUL_PRED'" +
			"      AND C1.RV_LOW_VALUE(+) = U.Titul_Pred" +
			"      AND C2.RV_DOMAIN(+) = 'TITUL_ZA'" +
			"      AND C2.RV_LOW_VALUE(+) = U.Titul_Za" +
			"     AND ou.ucitidno = u.ucitidno order by u.PRIJMENI, u.JMENO";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lang, lang, katedra, predmet,rokPlatnosti}));
  }

  /**
   * Zjisti cvicici na zaklade vypsanych studijnich akci.
   * Timto se resi ten problem, ze do STAGu sekretarky (nebo kdo???) nevypisuji k hlavickam predmetu nikoho krome garantu.
   *
   * @param katedra
   *            Zkratka pracoviste. Musi byt zadano.
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano.
   * @param rokVar
   *            Rok varianty predmetu. Musi byt zadano.
   * @return Seznam cvicicich. Polozky:
   *         <ul>
   *         <li>PK_UcitIDNO - BigDecimal - ID No ucitele.</li>
   *         <li>Jmeno - String - Jmeno ucitele.</li>
   *         <li>Prijmeni - String - Prijmeni ucitele.</li>
   *         <li>Titul_Pred - String - Predni titul.</li>
   *         <li>Titul_Za - String - Zadni titul.</li>
   *         <li>Ucitel - String - Cele jmeno vcetne titulu.</li>
   *         </ul>
   */
  public List getCviciciPodleStudijnichAkci(String katedra, String predmet, String rokVar, String lang) {
    String sql = "   SELECT DISTINCT RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni," +
			"	   DECODE(?, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred," +
			"	   DECODE(?, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za," +
			"	   DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel" +
			"     FROM Rozvrh_Akce RA, Ucitele U, CG_Ref_Codes C1, CG_Ref_Codes C2" +
			"    WHERE RA.Prac_Zkr = UPPER(?)" +
			"      AND RA.Zkr_Predm = UPPER(?)" +
			"      AND RA.Rok_Platnosti = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))" +
			"      AND RA.TypAkce = 'Cv'" +
			"      AND RA.UcitIDNO = U.UcitIDNO" +
			"      AND C1.RV_DOMAIN(+) = 'TITUL_PRED'" +
			"      AND C1.RV_LOW_VALUE(+) = U.Titul_Pred" +
			"      AND C2.RV_DOMAIN(+) = 'TITUL_ZA'" +
			"      AND C2.RV_LOW_VALUE(+) = U.Titul_Za";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lang, lang, katedra, predmet, rokVar}));
  }

	public List getCviciciPodleStudijnichAkciWithLogin(String katedra, String predmet, String rokPlatnosti, String lang) {
    String sql = "   SELECT DISTINCT RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni," +
			"	   DECODE(?, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred," +
			"	   DECODE(?, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za," +
			"	   DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel, ou.username as login" +
			"     FROM Rozvrh_Akce RA, Ucitele U, orion_ucitele ou,  CG_Ref_Codes C1, CG_Ref_Codes C2" +
			"    WHERE RA.Prac_Zkr = UPPER(?)" +
			"      AND RA.Zkr_Predm = UPPER(?)" +
			"      AND RA.Rok_Platnosti = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))" +
			"      AND RA.TypAkce = 'Cv'" +
			"      AND RA.UcitIDNO = U.UcitIDNO" +
			"      AND C1.RV_DOMAIN(+) = 'TITUL_PRED'" +
			"      AND C1.RV_LOW_VALUE(+) = U.Titul_Pred" +
			"      AND C2.RV_DOMAIN(+) = 'TITUL_ZA'" +
			"      AND C2.RV_LOW_VALUE(+) = U.Titul_Za" +
			"     AND ou.ucitidno = u.ucitidno order by u.PRIJMENI, u.JMENO";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String[]{lang, lang, katedra, predmet,rokPlatnosti}));
  }


	public List getAllOsobyNaPredmetu(String katedra, String predmet,String rok, String lang) {
		String sql =" select  'garant' as role, u.UCITIDNO as pk_ucitidno, u.JMENO, u.PRIJMENI, DECODE(:lang, 'cs', c1.RV_ABBREVIATION, 'sk', c1.RV_ABBREVIATION, NVL(c1.english, c1.RV_ABBREVIATION)) AS titul_pred, \n" +
		            "                            DECODE(:lang, 'cs', c2.RV_ABBREVIATION, 'sk', c2.RV_ABBREVIATION, NVL(c2.english, c2.RV_ABBREVIATION)) AS titul_za, \n" +
		            "                            DECODE(u.TITUL_PRED, NULL, NULL, c1.RV_ABBREVIATION||' ')||u.JMENO||' '||u.PRIJMENI||DECODE(u.TITUL_ZA, NULL, NULL,', '||c2.RV_ABBREVIATION) as ucitel \n" +
		            "                          from ucitele u, ucitele_predmetu up,  cg_ref_codes c1, cg_ref_codes c2 where up.ZKR_PREDM = UPPER(:predmet)  and up.PRAC_ZKR = UPPER(:katedra) \n" +
		            "\t\t                           and up.ROK_VARIANTY = :rok   and up.GARANT = 'A'  and u.UCITIDNO = up.UCITIDNO \n" +
		            "\t\t                           and c1.RV_DOMAIN(+) = 'TITUL_PRED'  and c1.RV_LOW_VALUE(+) = u.TITUL_PRED  and c2.RV_DOMAIN(+) = 'TITUL_ZA' \n" +
		            "\t\t                           and c2.RV_LOW_VALUE(+) = u.TITUL_ZA  \n" +
		            "\t\t             UNION \n" +
		            "\t\t             SELECT DISTINCT  'prednasejici' as role, RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni, \n" +
		            "\t\t                DECODE(:lang, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred, \n" +
		            "\t\t                DECODE(:lang, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za, \n" +
		            "\t\t                DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel \n" +
		            "\t\t                  FROM Rozvrh_Akce RA, Ucitele U, CG_Ref_Codes C1, CG_Ref_Codes C2 \n" +
		            "\t\t                 WHERE RA.Prac_Zkr = UPPER(:katedra) \n" +
		            "\t\t                   AND RA.Zkr_Predm = UPPER(:predmet) \n" +
		            "\t\t                   AND RA.Rok_Platnosti = nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE))) " +
		            "\t\t                   AND RA.TypAkce = 'P\u0159' \n" +
		            "\t\t                   AND RA.UcitIDNO = U.UcitIDNO \n" +
		            "\t\t                   AND C1.RV_DOMAIN(+) = 'TITUL_PRED' \n" +
		            "\t\t                   AND C1.RV_LOW_VALUE(+) = U.Titul_Pred \n" +
		            "\t\t                   AND C2.RV_DOMAIN(+) = 'TITUL_ZA' \n" +
		            "\t\t                   AND C2.RV_LOW_VALUE(+) = U.Titul_Za  \n" +
		            "\t\t             UNION \n" +
		            "\t\t             SELECT DISTINCT  'cvicici' as role,  RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni, \n" +
		            "\t\t                DECODE(:lang, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred, \n" +
		            "\t\t                DECODE(:lang, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za, \n" +
		            "\t\t                DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel \n" +
		            "\t\t                  FROM Rozvrh_Akce RA, Ucitele U,  CG_Ref_Codes C1, CG_Ref_Codes C2 \n" +
		            "\t\t                 WHERE RA.Prac_Zkr = UPPER(:katedra) \n" +
		            "\t\t                   AND RA.Zkr_Predm = UPPER(:predmet) \n" +
		            "\t\t                   AND RA.Rok_Platnosti =nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE)))" +
		            "\t\t                   AND RA.TypAkce = 'Se' \n" +
		            "\t\t                   AND RA.UcitIDNO = U.UcitIDNO \n" +
		            "\t\t                   AND C1.RV_DOMAIN(+) = 'TITUL_PRED' \n" +
		            "\t\t                   AND C1.RV_LOW_VALUE(+) = U.Titul_Pred \n" +
		            "\t\t                   AND C2.RV_DOMAIN(+) = 'TITUL_ZA' \n" +
		            "\t\t                   AND C2.RV_LOW_VALUE(+) = U.Titul_Za \n" +
		            "\t\t             UNION \n" +
		            "\t\t             SELECT DISTINCT 'seminarici' as role,  RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni, \n" +
		            "\t\t                DECODE(:lang, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred, \n" +
		            "\t\t                DECODE(:lang, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za, \n" +
		            "\t\t                DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel \n" +
		            "\t\t                  FROM Rozvrh_Akce RA, Ucitele U,  CG_Ref_Codes C1, CG_Ref_Codes C2 \n" +
		            "\t\t                 WHERE RA.Prac_Zkr = UPPER(:katedra) \n" +
		            "\t\t                   AND RA.Zkr_Predm = UPPER(:predmet) \n" +
		            "\t\t                   AND RA.Rok_Platnosti =nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE)))" +
		            "\t\t                   AND RA.TypAkce = 'Cv' \n" +
		            "\t\t                   AND RA.UcitIDNO = U.UcitIDNO \n" +
		            "\t\t                   AND C1.RV_DOMAIN(+) = 'TITUL_PRED' \n" +
		            "\t\t                   AND C1.RV_LOW_VALUE(+) = U.Titul_Pred \n" +
		            "\t\t                   AND C2.RV_DOMAIN(+) = 'TITUL_ZA' \n" +
		            "\t\t                   AND C2.RV_LOW_VALUE(+) = U.Titul_Za";
		 Map map = new HashMap(3);
		map.put("katedra",katedra);
		map.put("predmet",predmet);
		map.put("lang","cs");
		map.put("rok",rok);
		return getNamedParameterJdbcTemplate().queryForList(sql,map);
	}


	public List getAllOsobyNaPredmetuWithLogin(String katedra, String predmet, String rok,String lang) {
		String sql = "\t\t                           select  'garant' as s_role, u.UCITIDNO as pk_ucitidno, u.JMENO, u.PRIJMENI, DECODE(:lang, 'cs', c1.RV_ABBREVIATION, 'sk', c1.RV_ABBREVIATION, NVL(c1.english, c1.RV_ABBREVIATION)) AS titul_pred,\n" +
		             "                                DECODE(:lang, 'cs', c2.RV_ABBREVIATION, 'sk', c2.RV_ABBREVIATION, NVL(c2.english, c2.RV_ABBREVIATION)) AS titul_za,\n" +
		             "\t\t                            DECODE(u.TITUL_PRED, NULL, NULL, c1.RV_ABBREVIATION||' ')||u.JMENO||' '||u.PRIJMENI||DECODE(u.TITUL_ZA, NULL, NULL,', '||c2.RV_ABBREVIATION) as ucitel, ou.username as login\n" +
		             "\t\t                          from ucitele u, ucitele_predmetu up, orion_ucitele ou,  cg_ref_codes c1, cg_ref_codes c2 where up.ZKR_PREDM = UPPER(:predmet)  and up.PRAC_ZKR = UPPER(:katedra)\n" +
		             "\t\t                           and up.ROK_VARIANTY = nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE)))" +
		             "   and up.GARANT = 'A'  and u.UCITIDNO = up.UCITIDNO\n" +
		             "\t\t                           and c1.RV_DOMAIN(+) = 'TITUL_PRED'  and c1.RV_LOW_VALUE(+) = u.TITUL_PRED  and c2.RV_DOMAIN(+) = 'TITUL_ZA'\n" +
		             "\t\t                           and c2.RV_LOW_VALUE(+) = u.TITUL_ZA  and u.ucitidno = ou.ucitidno\n" +
		             "\t\t             UNION\n" +
		             "\t\t             SELECT DISTINCT 'prednasejici' as s_role,  RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni,\n" +
		             "\t\t                DECODE(:lang, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred,\n" +
		             "\t\t                DECODE(:lang, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za,\n" +
		             "\t\t                DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel, ou.username as login\n" +
		             "\t\t                  FROM Rozvrh_Akce RA, Ucitele U, orion_ucitele ou, CG_Ref_Codes C1, CG_Ref_Codes C2\n" +
		             "\t\t                 WHERE RA.Prac_Zkr = UPPER(:katedra)\n" +
		             "\t\t                   AND RA.Zkr_Predm = UPPER(:predmet)\n" +
		             "\t\t                   AND RA.Rok_Platnosti = nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE)))" +
		             "\t\t                   AND RA.TypAkce = 'P\u0159'\n" +
		             "\t\t                   AND RA.UcitIDNO = U.UcitIDNO\n" +
		             "\t\t                   AND C1.RV_DOMAIN(+) = 'TITUL_PRED'\n" +
		             "\t\t                   AND C1.RV_LOW_VALUE(+) = U.Titul_Pred\n" +
		             "\t\t                   AND C2.RV_DOMAIN(+) = 'TITUL_ZA'\n" +
		             "\t\t                   AND C2.RV_LOW_VALUE(+) = U.Titul_Za\n" +
		             "\t\t                   AND ou.ucitidno = u.ucitidno\n" +
		             "\t\t             UNION\n" +
		             "\t\t             SELECT DISTINCT  'seminarici' as s_role, RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni,\n" +
		             "\t\t                DECODE(:lang, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred,\n" +
		             "\t\t                DECODE(:lang, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za,\n" +
		             "\t\t                DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel, ou.username as login\n" +
		             "\t\t                  FROM Rozvrh_Akce RA, Ucitele U, orion_ucitele ou,  CG_Ref_Codes C1, CG_Ref_Codes C2\n" +
		             "\t\t                 WHERE RA.Prac_Zkr = UPPER(:katedra)\n" +
		             "\t\t                   AND RA.Zkr_Predm = UPPER(:predmet)\n" +
		             "\t\t                   AND RA.Rok_Platnosti =nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE)))" +
		             "\t\t                   AND RA.TypAkce = 'Se'\n" +
		             "\t\t                   AND RA.UcitIDNO = U.UcitIDNO\n" +
		             "\t\t                   AND C1.RV_DOMAIN(+) = 'TITUL_PRED'\n" +
		             "\t\t                   AND C1.RV_LOW_VALUE(+) = U.Titul_Pred\n" +
		             "\t\t                   AND C2.RV_DOMAIN(+) = 'TITUL_ZA'\n" +
		             "\t\t                   AND C2.RV_LOW_VALUE(+) = U.Titul_Za\n" +
		             "\t\t                  AND ou.ucitidno = u.ucitidno\n" +
		             "\t\t             UNION\n" +
		             "\t\t             SELECT DISTINCT  'cvicici' as s_role, RA.UcitIDNO AS PK_UcitIDNO, U.Jmeno AS Jmeno, U.Prijmeni AS Prijmeni,\n" +
		             "\t\t                DECODE(:lang, 'cs', C1.RV_Abbreviation, 'sk', C1.RV_Abbreviation, NVL(C1.English, C1.RV_Abbreviation)) AS Titul_Pred,\n" +
		             "\t\t                DECODE(:lang, 'cs', C2.RV_Abbreviation, 'sk', C2.RV_Abbreviation, NVL(C2.English, C2.RV_Abbreviation)) AS Titul_Za,\n" +
		             "\t\t                DECODE(U.Titul_Pred, NULL, NULL, C1.RV_Abbreviation||' ') || U.Jmeno || ' ' || U.Prijmeni || DECODE(U.Titul_Za, NULL, NULL,', '||C2.RV_Abbreviation) AS Ucitel, ou.username as login\n" +
		             "\t\t                  FROM Rozvrh_Akce RA, Ucitele U, orion_ucitele ou,  CG_Ref_Codes C1, CG_Ref_Codes C2\n" +
		             "\t\t                 WHERE RA.Prac_Zkr = UPPER(:katedra)\n" +
		             "\t\t                   AND RA.Zkr_Predm = UPPER(:predmet)\n" +
		             "\t\t                   AND RA.Rok_Platnosti =nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = trunc(SYSDATE)))" +
		             "\t\t                   AND RA.TypAkce = 'Cv'\n" +
		             "\t\t                   AND RA.UcitIDNO = U.UcitIDNO\n" +
		             "\t\t                   AND C1.RV_DOMAIN(+) = 'TITUL_PRED'\n" +
		             "\t\t                   AND C1.RV_LOW_VALUE(+) = U.Titul_Pred\n" +
		             "\t\t                   AND C2.RV_DOMAIN(+) = 'TITUL_ZA'\n" +
		             "\t\t                   AND C2.RV_LOW_VALUE(+) = U.Titul_Za\n" +
		             "\t\t                  AND ou.ucitidno = u.ucitidno order by prijmeni";
		 Map map = new HashMap(3);
		map.put("katedra",katedra);
		map.put("predmet",predmet);
		map.put("lang","cs");
		map.put("rok",rok);
		return getNamedParameterJdbcTemplate().queryForList(sql,map);
	}


	public List getZkousky(String katedra, String predmet, String rok_platnosti) {
		String sql = "SELECT t.*, u.jmeno, u.prijmeni FROM terminy t, ucitele u WHERE t.prac_zkr = :katedra AND t.zkr_predm = :predmet AND t.rok_platnosti = nvl(:rok_platnosti, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE))) AND t.datum >= SYSDATE AND t.ucitidno = u.ucitidno";
		Map map = new HashMap(3);
		map.put("katedra",katedra);
		map.put("predmet",predmet);
		map.put("rok_platnosti",rok_platnosti);
		return getNamedParameterJdbcTemplate().queryForList(sql,map);
	}

	public List getRokyVariantPredmetu(String katedra, String predmet) {
    String sql = " select p.ROK_VARIANTY from pred_varianty p where p.PRAC_ZKR = upper(?)	and p.ZKR_PREDM = upper(?) order by p.ROK_VARIANTY";
//    st.setString(1, pracZkr);
//    st.setString(2, zkrPredm);
    return getJdbcTemplate().queryForList(sql, new String [] {katedra, predmet});
  }


  /*
   * --------------------------------================================ getInfo =========================----------------------------------------------
   */
  /**
   * Podle zadanych parametru zjisti informace o predmetu. Vraci informace z tabulky pred_varianty
   *
   * @param katedra
   *            Zkratka pracoviste. Musi byt zadano
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano
   * @param rok
   *            Rok varianty predmetu. Musi byt zadano
   * @param locale
   *            locale
   * @return informace o predmetu. Polozky:
   *         <ul>
   *         <li><tt>'pk_prac_zkr' [String]</tt>- Zkratka pracoviste. <b>STAG </b>: <tt>'PRED_VARIANTY.PRAC_ZKR'</tt>
   *         <li><tt>'pk_rok_varianty' [String]</tt>- Rok varianty. <b>STAG </b>: <tt>'PRED_VARIANTY.ROK_VARIANTY'</tt>
   *         <li><tt>'pk_zkr_predm' [String]</tt>- Zkratka predmetu. <b>STAG </b>: <tt>'PRED_VARIANTY.ZKR_PREDM'</tt>
   *         <li><tt>'akred' [String]</tt>- Predmet je akreditovan. <b>STAG </b>: <tt>'PRED_VARIANTY.AKRED'</tt>
   *         <li><tt>'anotace' [String]</tt>- Anotace predmetu. <b>STAG </b>: <tt>'PRED_VARIANTY.CZ_ANOTACE'</tt> nebo <tt>'PRED_VARIANTY.AN_ANOTACE'</tt>
   *         <li><tt>'crd' [String]</tt>- Pocet kreditu za absolvovany predmet. <b>STAG </b>: <tt>'PRED_VARIANTY.CRD'</tt>
   *         <li><tt>'do_prumeru' [String]</tt>- Urcuje jestli se predmet pocita do prumeru. <b>STAG </b>: <tt>'PRED_VARIANTY.DO_PRUMERU' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'garant' [String]</tt>- Prijmeni garanta. <b>STAG </b>: <tt>'PRED_VARIANTY.POZNAMKA'</tt>
   *         <li><tt>'jednotek_cv' [BigDecimal]</tt>- Pocet jednotek kazdeho cviceni. <b>STAG </b>: <tt>'PRED_VARIANTY.JEDNOTEK_CV'</tt>
   *         <li><tt>'jednotek_pr' [BigDecimal]</tt>- Pocet jednotek prednasky. <b>STAG </b>: <tt>'PRED_VARIANTY.JEDNOTEK_PR'</tt>
   *         <li><tt>'jednotek_sem' [BigDecimal]</tt>- Pocet jednotek seminare. <b>STAG </b>: <tt>'PRED_VARIANTY.JEDNOTEK_SEM'</tt>
   *         <li><tt>'jednotka' [String]</tt>- Typ jednotky prednasek. <b>STAG </b>: <tt>'PRED_VARIANTY.JEDNOTKA_PR' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'jednotka_cv' [String]</tt>- Typ jednotky cviceni. <b>STAG </b>: <tt>'PRED_VARIANTY.JEDNOTKA.CV' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'jednotka_sem' [String]</tt>- Typ jednotky seminare. <b>STAG </b>: <tt>'PRED_VARIANTY.JEDNOTKA.SEM' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'nazev' [String]</tt>- Nazev predmetu <b>STAG </b>: <tt>'PRED_VARIANTY.CZ_NAZEV'</tt> nebo <tt>'PRED_VARIANTY.AN_NAZEV'</tt>
   *         <li><tt>'pozadavky' [String]</tt>- Pozadavky na splneni predmetu. <b>STAG </b>: <tt>'PRED_PROGRAMY.CZ_POZADAVKY'</tt> nebo <tt>'PRED_PROGRAMY.AN_POZADAVKY'</tt>
   *         <li><tt>'predz_za' [String]</tt>- Zapocet pred zkouskou. <b>STAG </b>: <tt>'PRED_VARIANTY.PREDZ_ZA' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'prehled_latky' [String]</tt>- Prehled latky. <b>STAG </b>: <tt>'PRED_PROGRAMY.CZ_PREHLED_LATKY'</tt> nebo <tt>'PRED_PROGRAMY.AN_PREHLED_LATKY'</tt>
   *         <li><tt>'typ_zk' [String]</tt>- Typ zkousky (zkouska, zapocet) <b>STAG </b>: <tt>'PRED_VARIANTY.TYP_ZK' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'url' [String]</tt>- URL predmetu. <b>STAG </b>: <tt>'PRED_PROGRAMY.URL'</tt>
   *         <li><tt>'vicezapis' [String]</tt>- Moznost zapsat opakovane splneny predmet. <b>STAG </b>: <tt>'PRED_VARIANTY.VYCEZAPIS' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'vyuka_ls' [String]</tt>- Vyuka v LS. <b>STAG </b>: <tt>'PRED_VARIANTY.VYUKA_LS'</tt>
   *         <li><tt>'vyuka_zs' [String]</tt>- Vyuka v ZS. <b>STAG </b>: <tt>'PRED_VARIANTY.VYUKA.ZS'</tt>
   *         </ul>
   */
  public HashMap getInfo(String katedra, String predmet, String rok, Locale locale) {
    String lang = locale.getLanguage();
    String sql = "  select\tp.prac_zkr as pk_prac_zkr, p.zkr_predm as pk_zkr_predm, p.rok_varianty as pk_rok_varianty,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', p.cz_nazev, 'sk', p.cz_nazev, NVL(p.AN_NAZEV, p.cz_nazev)) as nazev,  \n" +
                 "                     p.crd, p.vyuka_zs, p.vyuka_ls, p.poznamka as garant, p.akred,\n" +
                 "                     p.jednotek_cv, p.jednotek_pr, p.jednotek_sem,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', p.cz_anotace, 'sk', p.cz_anotace, NVL(p.AN_ANOTACE, p.cz_anotace)) as anotace,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', c1.RV_MEANING, 'sk', c1.RV_MEANING, NVL(c1.ENGLISH, c1.RV_MEANING)) as jednotka,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', c2.RV_MEANING, 'sk', c2.RV_MEANING, NVL(c2.ENGLISH, c2.RV_MEANING)) as jednotka_cv,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', c3.RV_MEANING, 'sk', c3.RV_MEANING, NVL(c3.ENGLISH, c3.RV_MEANING)) as jednotka_sem,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', c4.RV_MEANING, 'sk', c4.RV_MEANING, NVL(c4.ENGLISH, c4.RV_MEANING)) as typ_zk,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', c5.RV_MEANING, 'sk', c5.RV_MEANING, NVL(c5.ENGLISH, c5.RV_MEANING)) as predz_za,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', c6.RV_MEANING, 'sk', c6.RV_MEANING, NVL(c6.ENGLISH, c6.RV_MEANING)) as vicezapis,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', c7.RV_MEANING, 'sk', c7.RV_MEANING, NVL(c7.ENGLISH, c7.RV_MEANING)) as do_prumeru,\n" +
                 "          \t\t\tpp.url,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', pp.cz_pozadavky, 'sk', pp.cz_pozadavky, NVL(pp.AN_POZADAVKY, pp.cz_pozadavky)) as pozadavky,\n" +
                 "          \t\t\tDECODE(:lang, 'cs', pp.cz_prehled_latky, 'sk', pp.cz_prehled_latky, NVL(pp.AN_PREHLED_LATKY, pp.cz_prehled_latky)) as prehled_latky\n" +
                 "                from  pred_varianty p, cg_ref_codes c1, cg_ref_codes c2, cg_ref_codes c3, cg_ref_codes c4,\n" +
                 "                      cg_ref_codes c5, cg_ref_codes c6, cg_ref_codes c7, pred_programy pp\n" +
                 "               where  p.prac_zkr = UPPER(:zkr_prac)\n" +
                 "                 and  p.zkr_predm = UPPER(:zkr_pred)\n" +
                 "                 and  p.rok_varianty = nvl(:rok, (select ROK_PLATNOSTI from KALENDAR where datum = SYSDATE)) \n" +
                 "                 and  p.prac_zkr = pp.prac_zkr(+)\n" +
                 "                 and  p.zkr_predm = pp.zkr_predm(+)\n" +
                 "                 and  p.rok_varianty = pp.rok_varianty(+)\n" +
                 "                 and  p.jednotka_pr = c1.rv_low_value\n" +
                 "                 and  c1.rv_domain = 'JEDNOTKA_VYUKY'\n" +
                 "                 and  p.jednotka_cv = c2.rv_low_value\n" +
                 "                 and  c2.rv_domain = 'JEDNOTKA_VYUKY'\n" +
                 "                 and  p.jednotka_sem = c3.rv_low_value\n" +
                 "                 and  c3.rv_domain = 'JEDNOTKA_VYUKY'\n" +
                 "                 and  p.typ_zk = c4.rv_low_value\n" +
                 "                 and  c4.rv_domain = 'TYP_ZK_NEW'\n" +
                 "                 and  p.predz_za = c5.rv_low_value\n" +
                 "                 and  c5.rv_domain = 'ANO_NE'\n" +
                 "                 and  p.vicezapis = c6.rv_low_value\n" +
                 "                 and  c6.rv_domain = 'ANO_NE'\n" +
                 "                 and  p.do_prumeru = c7.rv_low_value\n" +
                 "                 and  c7.rv_domain = 'ANO_NE'\n" +
                 "               order by p.rok_varianty desc";
    return new HashMap(getJdbcTemplate().queryForMap(sql, new String [] {lang, lang, lang, lang, lang, lang, lang, lang, lang, lang, lang, katedra, predmet, rok}));
  }

  /**
   * Vraci seznam vsech podminujicich predmetu. Predmety ze stejne serie maji stejne aidno.
   *
   * @param katedra
   *            Zkratka pracoviste. Musi byt zadano
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano
   * @param locale
   *            locale
   * @return Seznam vsech podminujicich predmetu. olozky:
   *         <ul>
   *         <li><tt>'pk_prac_zkr' [String]</tt>- Zkratka pracoviste. <b>STAG </b>: <tt>'PRED_VARIANTY.PRAC_ZKR'</tt>
   *         <li><tt>'pk_zkr_predm' [String]</tt>- Zkratka predmetu. <b>STAG </b>: <tt>'PRED_VARIANTY.ZKR_PREDM'</tt>
   *         <li><tt>'aidno' [BigDecimal]</tt>- Id podmineni. <b>STAG </b>: <tt>'NP_POD.AIDNO'</tt>
   *         <li><tt>'nazev' [String]</tt>- Nazev predmetu <b>STAG </b>: <tt>'PRED_VARIANTY.CZ_NAZEV'</tt> nebo
   *         <tt>'PRED_VARIANTY.AN_NAZEV'</tt>
   *         </ul>
   */
  public ArrayList getPodminujici(String katedra, String predmet, Locale locale) {
    String lang = locale.getLanguage();
    String sql = " select  np.prac_zkr_podm as pk_prac_zkr, np.zkr_predm_podm as pk_zkr_predm, np.AIDNO," +
            "		DECODE(?, 'cs', p.cz_nazev, 'sk', p.cz_nazev, NVL(p.AN_NAZEV, p.cz_nazev)) as nazev from  np_pod np, pred_varianty p" +
            " where  np.PRAC_ZKR = upper(?)	 and np.ZKR_PREDM = upper(?)  and p.PRAC_ZKR = np.PRAC_ZKR_PODM and p.ZKR_PREDM = np.ZKR_PREDM_PODM" +
            "	   and p.ROK_VARIANTY = (select max(pr.rok_varianty) from pred_varianty pr where pr.PRAC_ZKR = np.PRAC_ZKR_PODM" +
            "							 	   and pr.ZKR_PREDM = np.ZKR_PREDM_PODM							) order  by 1, 2";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String [] {lang, katedra, predmet}));
  }

  /**
   * Vraci seznam vsech vylucujicich predmetu.
   *
   * @param katedra
   *            Zkratka pracoviste. Musi byt zadano
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano
   * @return Seznam vsech vylucujicich predmetu.
   *         <ul>
   *         <li><tt>'pk_prac_zkr' [String]</tt>- Zkratka pracoviste. <b>STAG </b>: <tt>'PRED_VARIANTY.PRAC_ZKR'</tt>
   *         <li><tt>'pk_zkr_predm' [String]</tt>- Zkratka predmetu. <b>STAG </b>: <tt>'PRED_VARIANTY.ZKR_PREDM'</tt>
   *         <li><tt>'nazev' [String]</tt>- Nazev predmetu <b>STAG </b>: <tt>'PRED_VARIANTY.CZ_NAZEV'</tt> nebo
   *         <tt>'PRED_VARIANTY.AN_NAZEV'</tt>
   *         </ul>
   */
  public ArrayList getVylucujici(String katedra, String predmet, Locale locale) {
    String lang = locale.getLanguage();
    String sql = "    select  nv.prac_zkr_vylu as pk_prac_zkr,            nv.zkr_predm_vylu as pk_zkr_predm," +
    "			DECODE(?, 'cs', p.cz_nazev, 'sk', p.cz_nazev, NVL(p.AN_NAZEV, p.cz_nazev)) as nazev      from  np_vyluc nv, pred_varianty p" +
    "     where  nv.prac_zkr = upper(?)       and  nv.zkr_predm = upper(?)	    and p.PRAC_ZKR = nv.PRAC_ZKR_vylu	    and p.ZKR_PREDM = nv.ZKR_PREDM_vylu" +
    "	    and p.ROK_VARIANTY = (select max(pr.rok_varianty)	   	   				  	 from pred_varianty pr						 where pr.PRAC_ZKR = nv.PRAC_ZKR_vylu" +
    "							 	   and pr.ZKR_PREDM = nv.ZKR_PREDM_vylu							)     order  by 1, 2";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String [] {lang, katedra, predmet}));
  }

  /**
   * Vraci seznam doporucene literatury k zadanemu predmetu predmetu
   *
   * @param katedra
   *            Zkratka pracoviste. Musi byt zadano
   * @param predmet
   *            Zkratka predmetu. Musi byt zadano
   * @param rok
   *            Rok varianty predmetu. Musi byt zadano
   * @param locale
   *            locale
   * @return Seznam literatury. Polozky:
   *         <ul>
   *         <li><tt>'pk_liteidno' [BigDecimal]</tt>- Id literatury. <b>STAG </b>: <tt>'CIS_LITER.LITEIDNO'</tt>
   *         <li><tt>'autor' [String]</tt>- Autor knihy. <b>STAG </b>: <tt>'CIS_LITER.AUTOR'</tt>
   *         <li><tt>'misto' [String]</tt>- Misto vydani knihy. <b>STAG </b>: <tt>'CIS_LITER.MISTO_VYDANI'</tt>
   *         <li><tt>'nazev' [String]</tt>- Nazev knihy. <b>STAG </b>: <tt>'CIS_LITER.NAZEV'</tt>
   *         <li><tt>'priorita' [String]</tt>- Priorita knihy. <b>STAG </b>:
   *         <tt>'CIS_LITER.DULEZITOST' -> 'CG_REF_CODES.RV_MEANING'</tt>
   *         <li><tt>'rok' [String]</tt>- Rok vydani. <b>STAG </b>: <tt>'CIS_LITER.ROK_VYDANI'</tt>
   *         <li><tt>'url' [String]</tt>- URL o knize. <b>STAG </b>: <tt>'CIS_LITER.URL'</tt>
   *         <li><tt>'fk_priorita' [String]</tt>- ID priority knihy. <b>STAG </b>: <tt>'CIS_LITER.DULEZITOST'</tt>
   *         </ul>
   */
  public ArrayList getLiteratura(String katedra, String predmet, String rok, Locale locale) {
    String lang = locale.getLanguage();
    String sql = "   select  fn_meaning2(pl.dulezitost, 'DULEZITOST_LITERATURY') as priorita,      decode(cl.autor, '&', NULL, cl.autor) as autor," +
    "	   cl.nazev, pl.dulezitost as fk_priorita,	   decode(cl.rok_vydani, '&', NULL, cl.rok_vydani) as rok," +
    "	   decode(cl.misto_vydani, '&', NULL, cl.misto_vydani) as misto,	   cl.url, cl.LITEIDNO as pk_liteidno from  pred_liter pl, cis_liter cl" +
    " where  pl.prac_zkr = upper(?)      and  pl.zkr_predm = upper(?)      and  pl.rok_varianty = nvl(?, (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE)))" +
    "      and  pl.liteidno = cl.liteidno  order  by pl.dulezitost desc";

    return new ArrayList(getJdbcTemplate().queryForList(sql, new String [] {katedra, predmet, rok}));
  }


	public List selectPredmetyFromPracoviste(String zkr_prac) {
		String sql = " select p.prac_zkr as pk_prac_zkr, p.zkr_predm as pk_zkr_predm, p.rok_varianty as pk_rok_varianty,  DECODE('cs', 'cs', p.cz_nazev, 'sk', p.cz_nazev, NVL(p.an_nazev, p.cz_nazev)) AS nazev_predmetu\n" +
		             "  from pred_varianty p where p.PRAC_ZKR = upper(:zkr_prac) " +
		             "  And p.ROK_VARIANTY = (select ROK_PLATNOSTI from KALENDAR where datum = to_date(SYSDATE))  order by p.PRAC_ZKR, p.ZKR_PREDM, p.ROK_VARIANTY";
		Map map = new HashMap(1);
		map.put("zkr_prac",zkr_prac);
		return getNamedParameterJdbcTemplate().queryForList(sql,map);		
	}

	
	public Map selectPredCvSem(String katedra, String predmet) {
		String sql = "SELECT p.jednotek_pr, p.jednotek_cv, p.jednotek_sem,\n" +
		             "  p.typ_zk, p.predz_za\n" +
		             " FROM pred_varianty  p WHERE prac_zkr = :katedra AND zkr_predm = :predmet AND rok_varianty in ('2007','2008')";
		Map map = new HashMap(2);
		map.put("katedra",katedra);
		map.put("predmet",predmet);
		List list = getNamedParameterJdbcTemplate().queryForList(sql, map);
		if (isDebugEnabled) {
			logger.debug("Parametry predmetu: "+list.toString());
		}
		return (Map) list.get(list.size()-1);
	}


}
